pub enum ApiVersion {
Php80 = 20_200_930,
Php81 = 20_210_902,
Php82 = 20_220_829,
Php83 = 20_230_831,
Php84 = 20_240_924,
Php85 = 20_250_925,
}Expand description
PHP API version enum.
This enum represents the supported PHP API versions and provides utilities for version detection and comparison.
Variants
Php80 = 20_200_930
PHP 8.0
Php81 = 20_210_902
PHP 8.1
Php82 = 20_220_829
PHP 8.2
Php83 = 20_230_831
PHP 8.3
Php84 = 20_240_924
PHP 8.4
Php85 = 20_250_925
PHP 8.5
Implementations
Sourceimpl ApiVersion
impl ApiVersion
Sourcepub fn supported_apis(self) -> Vec<ApiVersion>
pub fn supported_apis(self) -> Vec<ApiVersion>
Returns the API versions that are supported by this version.
For example, PHP 8.3 supports APIs from 8.0, 8.1, 8.2, and 8.3.
Sourcepub fn cfg_name(self) -> &'static str
pub fn cfg_name(self) -> &'static str
Returns the cfg flag name for this version (e.g., “php84”).
Sourcepub fn define_name(self) -> &'static str
pub fn define_name(self) -> &'static str
Returns the C preprocessor define name for this version.